=========
Changelog
=========

25.1
====

Released 20-01-2026

Initial development version. Adds core django-readers integration and type-safe
``Query`` API.

Otherwise undocumented.

Likely, do not use.
